@@ -13,10 +13,9 @@
 //    authors for a copy.
 //
 
-#include <stdlib.h>
-#include <sys/types.h>
-#include "kernel.h"
 #include "swapmeter.h"
+#include "kernel.h"
+#include <stdlib.h>
 
 
 SwapMeter::SwapMeter( XOSView *parent )
@@ -44,7 +43,7 @@ void SwapMeter::checkevent( void ) {
 }
 
 void SwapMeter::getswapinfo( void ) {
-	u_int64_t total = 0, used = 0;
+	uint64_t total = 0, used = 0;
 
 	BSDGetSwapInfo(&total, &used);
 
